@@ -9,14 +9,14 @@ def get_connect(uri,user,pwd):
     except Exception as error:
         print(error)
     if(connect==1):
-        return (True,driver)
+        return (driver)
     else:
         print("please check your hostname , userid and password")
-        return (False,driver)
+        
 ##get the count
 def count_node(uri,user,pwd):
-       
-        con,driver=get_connect(uri,user,pwd)
+       if driver is not None:   
+        driver=get_connect(uri,user,pwd)
         if(con):
             session=driver.session()
             count_query="""match (n) return count(n) as count"""
